//
// Project Name: Green Ball Simple Game
//
// Author: Matthew Weathers
// Date  : 5-November-2000
//
// This demonstrates a simple game, with a score, lives and a 
//      Game Loop that allows you to play more than one game
//      before quitting.

#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <time.h>
#include <string.h>
#include "graphics2.h"

#define ESC 0x1b

const int MAX_X = 640;
const int MAX_Y = 480;

void drawOpeningScreen();
void drawClosingScreen();
void drawBox(int, int, int);
void showLives(int);
void showScore(int);

void main() 
{
	srand( (unsigned int) time(NULL));  // Seed the random number generator
	int GraphDriver=0,GraphMode=0;
	initgraph( &GraphDriver, &GraphMode, "", MAX_X, MAX_Y ); // Start Window
	char tempstring[80]="unused";

	// Declare variables
	int mouseX, mouseY;
	float x_pos;
	float x_vel;
	float x_prev;
	int score,lives;
	float dist_squared;

	bool gameOver;
	bool playAnotherGame;
	bool validResponse;
	char keyPressed;

	//Call a function to draw a fancy title screen
	drawOpeningScreen();
	getch();
	cleardevice();

	playAnotherGame = true;
	while(playAnotherGame) {

		// Start a new game
		cleardevice();
		score = 0;
		lives = 3;
		showScore(score);
		showLives(lives);

		x_pos = MAX_X / 2.0;
		x_vel = 3.0;
		x_prev = x_pos;

		setcolor(WHITE);
		outtextxy(20,20,"Press ESC or Q to quit Game.");
		outtextxy(20,50,"Click on green ball to get points");

		gameOver=false;
		while (gameOver==false) {

			//Main part of the game goes here

			x_pos += x_vel;
			drawBox(int(x_prev), 300, BLACK);
			drawBox(int(x_pos), 300, GREEN);
			x_prev=x_pos;
			if((x_pos<40) || (x_pos>MAX_X-40)) x_vel *= -1.5;
			if (x_vel>40.0) x_vel=2.0;
			if (x_pos<-100 || x_pos>MAX_X+100) x_pos=100;

			// Check keyboard
			if (kbhit()) {
				keyPressed=getch();

				switch(keyPressed) {
				case ESC: case 'q': case 'Q':
					//Quit
					gameOver = true;
					break;
				default:
					// Unrecognized key, do nothing
					break;
				}
			} // end of if kbhit

			// Check mouse
			if ( mouseup() ) {
				mouseX = mouseclickx();
				mouseY = mouseclicky();

				setcolor(YELLOW);
				fillellipse(mouseX, mouseY, 30, 30);
				//Collision detect
				dist_squared = (mouseX-x_pos)*(mouseX-x_pos)+(mouseY-300)*(mouseY-300);
				if (dist_squared < 40*40) {
					score += 50;
					showScore(score);
				} else {
					lives = lives-1;
					if (lives==0){
						gameOver = true;
					}
					showLives(lives);
				}

			} // end of if mouseup


			//at end of main game loop (while gameOver==false)
			delay(50);
		}

		//Game Over.  Ask if they want to play again
		setcolor(YELLOW);
		outtextxy(25, 425, "Game Over. Play again? (Y/N)");
		validResponse=false;
		do {
			keyPressed = getch();
			if ((keyPressed=='y') || (keyPressed=='Y')) {
					playAnotherGame = true;
					validResponse=true;
			}
			if ((keyPressed=='n') || (keyPressed=='N') || (keyPressed==ESC)) {
					playAnotherGame = false;
					validResponse=true;
			}
		} while (validResponse==false);

	}
	drawClosingScreen();

	getch(); //Wait for a key. (When main function ends, the window will close)
} // end of main()

void drawBox(int x, int y, int color){
	setcolor(color);
	setfillstyle(SOLID_FILL, color);
	fillellipse(x,y,10,10);
}

void drawOpeningScreen() {
	setcolor(LIGHTGRAY);
	setfillstyle(SOLID_FILL,LIGHTGRAY);
	bar(110,110, 550, 350);

	setcolor(BLUE);
	setfillstyle(SOLID_FILL,BLUE);
	bar(100,100, 540, 340);

	setcolor(WHITE);
	settextstyle(TRIPLEX_FONT, HORIZ_DIR, 2);
	outtextxy(180, 150, "Welcome to BLANK");
	outtextxy(180, 170, "by CSCI105 Student");

	outtextxy(300, 440, "Press any key...");
}

void drawClosingScreen() {
	cleardevice();

	setcolor(RED);
	outtextxy(180, 150, "Thanks for playing");

	setcolor(WHITE);
	outtextxy(300, 440, "Press any key to quit...");
}

void showLives(int lives){
	char tempstring[80];

	sprintf(tempstring, "Lives: %d", lives);
	outtextxy(MAX_X-200, 100, tempstring);
}

void showScore(int lives){
	char tempstring[80];

	sprintf(tempstring, "Score: %d", lives);
	outtextxy(MAX_X-200, 150, tempstring);
}

